All Classes and Interfaces

Class
Description
BungeeCord Messaging interface.
BungeeCord request interface.
Connects the sending audience to a server.
Connects a player to a server.
Forwards data to a server or all servers.
Forwards data to a specific player.
Requests the server a player is connected to.
Requests the server the sending audience is connected to.
Requests the list of all servers.
Requests the IP address of the sending audience.
Requests the IP address of a player.
Kicks a player from the server with a reason.
Kicks a player from the server with a reason.
Sends a message to a player.
Sends a raw message to a player.
Requests the player count of a server.
Requests the player list of a server.
Requests the IP address and port of a server.
Requests the UUID of the sending audience.
Requests the UUID of a player.
BungeeCord response interface.
A response to forward a message to a specific channel.
A response containing the player name and server name.
A response containing the server name.
A response containing a list of server names.
A response containing the IP address and port of the server.
A response containing the player name, IP address, and port of another player.
A response containing the server name and the number of players online.
A response containing the server name and a list of player names.
A response containing the server name, IP address, and port.
A response containing a UUID.
A response containing a player name and UUID.