Record Class BungeeRequest.ServerIP
java.lang.Object
java.lang.Record
dev.kerman.freight.BungeeRequest.ServerIP
- Record Components:
serverName- The name of the server to get the IP and port for. (Defined in your proxy config)
- All Implemented Interfaces:
BungeeMessage, BungeeRequest
- Enclosing interface:
BungeeRequest
public static record BungeeRequest.ServerIP(String serverName)
extends Record
implements BungeeRequest
Requests the IP address and port of a server.
-
Nested Class Summary
Nested classes/interfaces inherited from interface BungeeRequest
BungeeRequest.Connect, BungeeRequest.ConnectOther, BungeeRequest.Forward, BungeeRequest.ForwardToPlayer, BungeeRequest.GetPlayerServer, BungeeRequest.GetServer, BungeeRequest.GetServers, BungeeRequest.IP, BungeeRequest.IPOther, BungeeRequest.KickPlayer, BungeeRequest.KickPlayerRaw, BungeeRequest.Message, BungeeRequest.MessageRaw, BungeeRequest.PlayerCount, BungeeRequest.PlayerList, BungeeRequest.ServerIP, BungeeRequest.UUID, BungeeRequest.UUIDOther -
Field Summary
FieldsFields inherited from interface BungeeMessage
ALL, ONLINE -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionfinal booleanIndicates whether some other object is "equal to" this one.final inthashCode()Returns a hash code value for this object.Returns the value of theserverNamerecord component.final StringtoString()Returns a string representation of this record class.Methods inherited from interface BungeeMessage
send, send, sendSingle, toClientPacket, toPacket
-
Field Details
-
SERIALIZER
-
-
Constructor Details
-
ServerIP
Creates an instance of aServerIPrecord class.- Parameters:
serverName- the value for theserverNamerecord component
-
-
Method Details
-
toString
-
hashCode
-
equals
Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. All components in this record class are compared withObjects::equals(Object,Object). -
serverName
Returns the value of theserverNamerecord component.- Returns:
- the value of the
serverNamerecord component
-