Record Class BungeeRequest.UUIDOther

java.lang.Object
java.lang.Record
dev.kerman.freight.BungeeRequest.UUIDOther
Record Components:
playerName - The name of the player to get the UUID for.
All Implemented Interfaces:
BungeeMessage, BungeeRequest
Enclosing interface:
BungeeRequest

public static record BungeeRequest.UUIDOther(String playerName) extends Record implements BungeeRequest
Requests the UUID of a player.
  • Field Details

  • Constructor Details

    • UUIDOther

      public UUIDOther(String playerName)
      Creates an instance of a UUIDOther record class.
      Parameters:
      playerName - the value for the playerName record component
    • UUIDOther

      public UUIDOther(Pointered player)
  • Method Details

    • toString

      public final String toString()
      Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components.
      Specified by:
      toString in class Record
      Returns:
      a string representation of this object
    • hashCode

      public final int hashCode()
      Returns a hash code value for this object. The value is derived from the hash code of each of the record components.
      Specified by:
      hashCode in class Record
      Returns:
      a hash code value for this object
    • equals

      public final boolean equals(Object o)
      Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. All components in this record class are compared with Objects::equals(Object,Object).
      Specified by:
      equals in class Record
      Parameters:
      o - the object with which to compare
      Returns:
      true if this object is the same as the o argument; false otherwise.
    • playerName

      public String playerName()
      Returns the value of the playerName record component.
      Returns:
      the value of the playerName record component