Record Class BungeeRequest.UUIDOther
java.lang.Object
java.lang.Record
dev.kerman.freight.BungeeRequest.UUIDOther
- Record Components:
playerName- The name of the player to get the UUID for.
- All Implemented Interfaces:
BungeeMessage, BungeeRequest
- Enclosing interface:
BungeeRequest
public static record BungeeRequest.UUIDOther(String playerName)
extends Record
implements BungeeRequest
Requests the UUID of a player.
-
Nested Class Summary
Nested classes/interfaces inherited from interface BungeeRequest
BungeeRequest.Connect, BungeeRequest.ConnectOther, BungeeRequest.Forward, BungeeRequest.ForwardToPlayer, BungeeRequest.GetPlayerServer, BungeeRequest.GetServer, BungeeRequest.GetServers, BungeeRequest.IP, BungeeRequest.IPOther, BungeeRequest.KickPlayer, BungeeRequest.KickPlayerRaw, BungeeRequest.Message, BungeeRequest.MessageRaw, BungeeRequest.PlayerCount, BungeeRequest.PlayerList, BungeeRequest.ServerIP, BungeeRequest.UUID, BungeeRequest.UUIDOther -
Field Summary
FieldsFields inherited from interface BungeeMessage
ALL, ONLINE -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionfinal booleanIndicates whether some other object is "equal to" this one.final inthashCode()Returns a hash code value for this object.Returns the value of theplayerNamerecord component.final StringtoString()Returns a string representation of this record class.Methods inherited from interface BungeeMessage
send, send, sendSingle, toClientPacket, toPacket
-
Field Details
-
SERIALIZER
-
-
Constructor Details
-
UUIDOther
Creates an instance of aUUIDOtherrecord class.- Parameters:
playerName- the value for theplayerNamerecord component
-
UUIDOther
-
-
Method Details
-
toString
-
hashCode
-
equals
Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. All components in this record class are compared withObjects::equals(Object,Object). -
playerName
Returns the value of theplayerNamerecord component.- Returns:
- the value of the
playerNamerecord component
-